<?php
/**
 * Plugin Name: Plugin List Exporter
 * Description: Creates a list of all installed plugins and themes with their version numbers, along with the site name, URL, and WordPress version, and provides a download link.
 * Version: 1.4
 * Author: SB
 */

// Ensure this file is being included by WordPress.
defined('ABSPATH') or die('Direct script access disallowed.');

function ple_generate_plugin_list() {
    $site_name = get_bloginfo('name');
    $site_url = get_bloginfo('url');
    $wp_version = get_bloginfo('version');
    $plugins = get_plugins();
    $themes = wp_get_themes();

    $list = "Site Name, $site_name\n";
    $list .= "Site URL, $site_url\n";
    $list .= "WordPress Version, $wp_version\n\n";
    $list .= "Plugins:\n";
    $list .= "Plugin Name, Version\n";

    foreach ($plugins as $plugin) {
        $list .= $plugin['Name'] . ', ' . $plugin['Version'] . "\n";
    }

    $list .= "\nThemes:\n";
    $list .= "Theme Name, Version\n";

    foreach ($themes as $theme) {
        $list .= $theme->get('Name') . ', ' . $theme->get('Version') . "\n";
    }

    return $list;
}

function ple_download_plugin_list() {
    if (!current_user_can('manage_options')) {
        return;
    }

    if (isset($_GET['download_plugin_list'])) {
        $site_name = get_bloginfo('name');
        $sanitized_site_name = sanitize_title($site_name);
        $filename = $sanitized_site_name . '-plugin-list.csv';

        header('Content-Type: text/csv');
        header('Content-Disposition: attachment; filename="' . $filename . '"');
        echo ple_generate_plugin_list();
        exit;
    }
}
add_action('admin_init', 'ple_download_plugin_list');

function ple_admin_menu() {
    add_submenu_page(
        'tools.php',
        'Plugin List Exporter',
        'Plugin List Exporter',
        'manage_options',
        'plugin-list-exporter',
        'ple_admin_page'
    );
}
add_action('admin_menu', 'ple_admin_menu');

function ple_admin_page() {
    ?>
    <div class="wrap">
        <h1>Plugin List Exporter</h1>
        <p>Click the button below to download a list of:</p>
        <ul>
            <li>Site Name</li>
            <li>Site URL</li>
            <li>WordPress Version</li>
            <li>Installed Plugins and their Versions</li>
            <li>Installed Themes and their Versions</li>
        </ul>
        <a href="<?php echo admin_url('tools.php?page=plugin-list-exporter&download_plugin_list=1'); ?>" class="button button-primary">Download Plugin and Theme List</a>
    </div>
    <div style="margin-top: 20px; display: flex; align-items: center;">
        <span>Created By:</span>
        <img src="https://wpscriptly.com/wp-content/uploads/2024/05/wpsc-logo-256.png" alt="WpScriptly Logo" style="width: 16px; height: 16px; margin-left: 5px;">
        <a href="https://wpscriptly.com" target="_blank" style="margin-left: 5px;">
            WpScriptly
        </a>
    </div>
    <?php
}
